@@ -12,9 +12,9 @@ from ..broker import MessageBroker
 from ..aient.aient.models import chatgpt
 from ..aient.aient.plugins import get_function_call_list, registry
 from ..prompt import worker_system_prompt, instruction_system_prompt, Goal
-from ..utils import extract_xml_content, get_current_screen_image_message, replace_xml_content, register_mcp_tools, setup_logger
+from ..utils import extract_xml_content, get_current_screen_image_message, register_mcp_tools, setup_logger
 from ..aient.aient.models.chatgpt import ModelNotFoundError, TaskComplete, RetryFailedError, InputTokenCountExceededError, BadRequestError
-from ..aient.aient.architext.architext import Messages, SystemMessage, UserMessage, AssistantMessage, ToolCalls, ToolResults, Texts, RoleMessage, Images, Files
+from ..aient.aient.architext.architext import Messages, UserMessage, Texts
 
 try:
     from importlib import metadata
@@ -39,7 +39,7 @@ class BaseAgent:
         self.config = agent_config
         self.logger = agent_config.get("logger", None)
         self.cache_messages = cache_messages
-        if cache_messages and isinstance(cache_messages, bool) and cache_messages == True:
+        if cache_messages and isinstance(cache_messages, bool) and cache_messages:
             self.cache_messages = Messages.load(self.pkl_file)
         self.broker = broker
         self.listen_topic = listen_topic
@@ -94,10 +94,11 @@ class InstructionAgent(BaseAgent):
 
     async def handle_message(self, message: Dict):
         """Receives a worker response, generates the next instruction, and publishes it."""
+        goal = await message["conversation"].provider("goal").render() if message["conversation"].provider("goal") else Goal(self.goal)
 
         instruction_prompt = "".join([
                 "</work_agent_conversation_end>\n\n",
-                f"任务目标: {self.goal}\n\n",
+                f"任务目标: {goal}\n\n",
                 f"任务目标新变化：\n{self.goal_diff}\n\n" if self.goal_diff else "",
                 "在 tag <work_agent_conversation_start>...</work_agent_conversation_end> 之前的对话历史都是工作智能体的对话历史。\n\n",
                 "根据以上对话历史和目标，请生成下一步指令。如果任务已完成，指示工作智能体调用task_complete工具。\n\n",
@@ -118,14 +119,14 @@ class InstructionAgent(BaseAgent):
             raw_response = await self.agent.ask_async(instruction_prompt)
         except ModelNotFoundError as e:
             raise Exception(str(e))
-        except RetryFailedError as e:
+        except RetryFailedError:
             self.logger.error("❌ Commander retry failed, retrying...")
             self.broker.publish(message, self.error_topic)
             return
-        except InputTokenCountExceededError as e:
+        except InputTokenCountExceededError:
             self.broker.publish({"status": "error", "result": "The request body is too long, please try again."}, self.status_topic)
             return
-        except BadRequestError as e:
+        except BadRequestError:
             self.broker.publish({"status": "error", "result": "Bad request error!"}, self.status_topic)
             return
 
@@ -137,7 +138,7 @@ class InstructionAgent(BaseAgent):
                 instruction = re.sub(r'^<task_complete>([\D\d\s]+)<\/task_complete>$', '', instruction, flags=re.MULTILINE)
                 instruction = (
                     "任务描述：\n"
-                    f"<goal>{self.goal}</goal>\n\n"
+                    f"{goal}\n\n"
                     "你作为指令的**执行者**，而非任务的**规划师**，你必须严格遵循以下单步工作流程：\n"
                     "**执行指令**\n"
                     "   - **严格遵从：** 只执行我当前下达的明确指令。在我明确给出下一步指令前，绝不擅自行动或推测、执行任何未明确要求的后续步骤。\n"
@@ -191,13 +192,13 @@ class WorkerAgent(BaseAgent):
         except TaskComplete as e:
             self.broker.publish({"status": "finished", "result": e.completion_message}, self.status_topic)
             return
-        except InputTokenCountExceededError as e:
+        except InputTokenCountExceededError:
             self.broker.publish({"status": "error", "result": "The request body is too long, please try again."}, self.status_topic)
             return
-        except BadRequestError as e:
+        except BadRequestError:
             self.broker.publish({"status": "error", "result": "Bad request error!"}, self.status_topic)
             return
-        except RetryFailedError as e:
+        except RetryFailedError:
             self.logger.error("❌ Worker retry failed, retrying...")
             self.broker.publish(message, self.error_topic)
             return
@@ -207,7 +208,8 @@ class WorkerAgent(BaseAgent):
             self.broker.publish(message, self.error_topic)
         else:
             self.broker.publish({"status": "new_message", "result": "\n✅ 工作智能体:\n" + response}, self.status_topic)
-            self.agent.conversation["default"][-1].rstrip(Texts)
+            if self.agent.conversation["default"][-1].role == "user":
+                self.agent.conversation["default"][-1].rstrip(Texts)
             self.broker.publish({
                 "conversation": self.agent.conversation["default"]
             }, self.publish_topic)
@@ -244,7 +246,7 @@ class BrokerWorker:
 
         # 创建一个文件处理器，将日志写入任务自己的目录
         log_file_path = cache_dir / "agent.log"
-        self.logger = setup_logger(f"task_{self.work_dir.name}", log_file_path)
+        self.logger = setup_logger(str(log_file_path.parent.parent.absolute()), log_file_path)
         self.logger.info(f"beswarm version: {version}")
         self.logger.info(f"Logger for task '{self.goal}' initialized. Log file: {log_file_path}")
 
@@ -259,7 +261,8 @@ class BrokerWorker:
             all_mcp_tools = await self.mcp_manager.get_all_tools()
             self.tools.extend([tool.name for tool in sum(all_mcp_tools.values(), [])])
         self.tools = [item for item in self.tools if not isinstance(item, dict)]
-        if "task_complete" not in self.tools: self.tools.append("task_complete")
+        if "task_complete" not in self.tools:
+            self.tools.append("task_complete")
         self.tools_json = [value for _, value in get_function_call_list(self.tools).items()]
 
     def _task_status_subscriber(self, message: Dict):
@@ -295,7 +298,7 @@ class BrokerWorker:
             "engine": os.getenv("FAST_MODEL") or os.getenv("MODEL"),
             "system_prompt": copy.deepcopy(worker_system_prompt),
             "print_log": True, "temperature": 0.5, "function_call_max_loop": 100, "logger": self.logger,
-            "check_done": True
+            "check_done": os.getenv("CHECK_DONE", "true").lower() in ("true", "1", "t", "yes")
         }
 
         instruction_agent = InstructionAgent(
