@@ -6,6 +6,7 @@ import hashlib
 import mimetypes
 import uuid
 import threading
+import copy
 from dataclasses import dataclass
 from abc import ABC, abstractmethod
 from typing import List, Dict, Any, Optional, Union, Callable
@@ -104,9 +105,10 @@ class ContextProvider(ABC):
         return NotImplemented
 
 class Texts(ContextProvider):
-    def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None, visible: bool = True):
+    def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: Optional[str] = None, visible: bool = True, newline: bool = False):
         if text is None and name is None:
             raise ValueError("Either 'text' or 'name' must be provided.")
+        self.newline = newline
 
         # Ensure that non-callable inputs are treated as strings
         if not callable(text):
@@ -127,6 +129,11 @@ class Texts(ContextProvider):
         else:
             _name = name
         super().__init__(_name, visible=visible)
+        if not self._is_dynamic:
+            self._cached_content = self.content
+            # The content is cached, but it's still "stale" from the perspective
+            # of the async refresh cycle. Let the first refresh formalize it.
+            self._is_stale = True
 
     async def refresh(self):
         if self._is_dynamic:
@@ -177,6 +184,15 @@ class Texts(ContextProvider):
         # Just restore the dictionary. The transformation is one-way.
         self.__dict__.update(state)
 
+    def __deepcopy__(self, memo):
+        """Custom deepcopy to preserve dynamic content by copying the callable."""
+        cls = self.__class__
+        result = cls.__new__(cls)
+        memo[id(self)] = result
+        for k, v in self.__dict__.items():
+            setattr(result, k, copy.deepcopy(v, memo))
+        return result
+
     def __eq__(self, other):
         if not isinstance(other, Texts):
             return NotImplemented
@@ -186,10 +202,30 @@ class Texts(ContextProvider):
         # For static content, compare the actual content.
         return self.content == other.content
 
+    def __iadd__(self, other):
+        if isinstance(other, str):
+            new_text = self.content + other
+            self.update(new_text)
+            return self
+        return NotImplemented
+
+    def __add__(self, other):
+        if isinstance(other, str):
+            # Create a new instance of the same class with the combined content
+            return type(self)(text=self.content + other, name=self.name, visible=self.visible, newline=self.newline)
+        elif isinstance(other, Message):
+            new_items = [self] + other.provider()
+            return type(other)(*new_items)
+        return NotImplemented
+
 class Tools(ContextProvider):
     def __init__(self, tools_json: Optional[List[Dict]] = None, name: str = "tools", visible: bool = True):
         super().__init__(name, visible=visible)
         self._tools_json = tools_json or []
+        # Pre-render and cache the content, but leave it stale for the first refresh
+        if self._tools_json:
+            self._cached_content = f"<tools>{str(self._tools_json)}</tools>"
+        self._is_stale = True
     def update(self, tools_json: List[Dict]):
         self._tools_json = tools_json
         self.mark_stale()
@@ -207,73 +243,116 @@ class Files(ContextProvider):
     def __init__(self, *paths: Union[str, List[str]], name: str = "files", visible: bool = True):
         super().__init__(name, visible=visible)
         self._files: Dict[str, str] = {}
+        self._file_sources: Dict[str, Dict] = {}
 
         file_paths: List[str] = []
         if paths:
-            # Handle the case where the first argument is a list of paths, e.g., Files(['a', 'b'])
             if len(paths) == 1 and isinstance(paths[0], list):
                 file_paths.extend(paths[0])
-            # Handle the case where arguments are individual string paths, e.g., Files('a', 'b')
             else:
                 file_paths.extend(paths)
 
         if file_paths:
             for path in file_paths:
-                try:
-                    with open(path, 'r', encoding='utf-8') as f:
-                        self._files[path] = f.read()
-                except FileNotFoundError:
-                    logging.warning(f"File not found during initialization: {path}. Skipping.")
-                except Exception as e:
-                    logging.error(f"Error reading file {path} during initialization: {e}")
+                self.update(path)
+
+    def _read_from_disk(self, path: str, head: Optional[int] = None) -> str:
+        """Reads content from a file on disk, respecting the head parameter."""
+        try:
+            with open(path, 'r', encoding='utf-8') as f:
+                if head is not None and head > 0:
+                    lines = []
+                    for _ in range(head):
+                        try:
+                            lines.append(next(f))
+                        except StopIteration:
+                            break
+                    return "".join(lines).rstrip('\n')
+                else:
+                    return f.read()
+        except FileNotFoundError:
+            raise
+        except Exception as e:
+            logging.error(f"Error reading file {path}: {e}")
+            return f"[Error: Could not read file at path '{path}': {e}]"
 
     async def refresh(self):
         """
-        Overrides the default refresh behavior. It synchronizes the content of
-        all tracked files with the file system. If a file is not found, its
-        content is updated to reflect the error.
+        Synchronizes content for files sourced from disk.
+        Content set manually is overwritten if the file exists, but preserved if it does not.
         """
         is_changed = False
-        for path in list(self._files.keys()):
-            try:
-                with open(path, 'r', encoding='utf-8') as f:
-                    new_content = f.read()
-                if self._files.get(path) != new_content:
-                    self._files[path] = new_content
-                    is_changed = True
-            except FileNotFoundError:
-                error_msg = f"[Error: File not found at path '{path}']"
-                if self._files.get(path) != error_msg:
-                    self._files[path] = error_msg
-                    is_changed = True
-            except Exception as e:
-                error_msg = f"[Error: Could not read file at path '{path}': {e}]"
-                if self._files.get(path) != error_msg:
-                    self._files[path] = error_msg
-                    is_changed = True
+        for path, spec in list(self._file_sources.items()):
+            if spec.get('source') == 'disk':
+                try:
+                    head = spec.get('head')
+                    new_content = self._read_from_disk(path, head)
+                    if self._files.get(path) != new_content:
+                        self._files[path] = new_content
+                        is_changed = True
+                except FileNotFoundError:
+                    error_msg = f"[Error: File not found at path '{path}']"
+                    if self._files.get(path) != error_msg:
+                        self._files[path] = error_msg
+                        is_changed = True
+            elif spec.get('source') == 'manual':
+                try:
+                    # File exists, so we must overwrite manual content.
+                    head = spec.get('head')
+                    new_content = self._read_from_disk(path, head)
+                    if self._files.get(path) != new_content:
+                        self._files[path] = new_content
+                        is_changed = True
+                    # If we are here, manual content was overwritten by disk content,
+                    # so we should update the source.
+                    self._file_sources[path] = {'source': 'disk'}
+
+                except FileNotFoundError:
+                    # File does not exist, so we keep the manual content. No change.
+                    pass
 
         if is_changed:
             self.mark_stale()
-
         await super().refresh()
 
-    def update(self, path: str, content: Optional[str] = None):
+    def update(self, path: str, content: Optional[str] = None, head: Optional[Union[int, str]] = None):
         """
-        Updates a single file. If content is provided, it updates the file in
-        memory. If content is None, it reads the file from disk.
+        Updates a single file's content and its source specification.
         """
-        if content is not None:
-            self._files[path] = content
-        else:
+        if head is not None:
             try:
-                with open(path, 'r', encoding='utf-8') as f:
-                    self._files[path] = f.read()
+                head = int(head)
+            except (ValueError, TypeError):
+                logging.warning(f"Invalid 'head' parameter for file '{path}': {head}. Must be an integer. Ignoring.")
+                head = None
+
+        if content is not None:
+            # New logic: if head is also provided, decide what to do with content.
+            if head is not None and head > 0:
+                try:
+                    # If file exists, prioritize reading from disk.
+                    self._files[path] = self._read_from_disk(path, head)
+                    self._file_sources[path] = {'source': 'disk', 'head': head}
+                except FileNotFoundError:
+                    # If file does not exist, use the provided content's head.
+                    lines = content.split('\n')
+                    self._files[path] = "\n".join(lines[:head])
+                    self._file_sources[path] = {'source': 'manual', 'head': head}
+            else:
+                # Original logic for when only content is provided.
+                self._files[path] = content
+                self._file_sources[path] = {'source': 'manual'}
+        else:
+            # Original logic for when only path (and optional head) is provided.
+            try:
+                self._files[path] = self._read_from_disk(path, head)
+                spec = {'source': 'disk'}
+                if head is not None and head > 0:
+                    spec['head'] = head
+                self._file_sources[path] = spec
             except FileNotFoundError:
-                logging.error(f"File not found for update: {path}.")
                 self._files[path] = f"[Error: File not found at path '{path}']"
-            except Exception as e:
-                logging.error(f"Error reading file for update {path}: {e}.")
-                self._files[path] = f"[Error: Could not read file at path '{path}': {e}]"
+                self._file_sources[path] = {'source': 'disk'}
         self.mark_stale()
     async def render(self) -> str:
         if not self._files: return None
@@ -288,6 +367,9 @@ class Images(ContextProvider):
     def __init__(self, url: str, name: Optional[str] = None, visible: bool = True):
         super().__init__(name or url, visible=visible)
         self.url = url
+        if self.url.startswith("data:"):
+            self._cached_content = self.url
+        self._is_stale = True
     def update(self, url: str):
         self.url = url
         self.mark_stale()
@@ -311,17 +393,21 @@ class Images(ContextProvider):
 
 # 3. 消息类 (已合并 MessageContent)
 class Message(ABC):
-    def __init__(self, role: str, *initial_items: Union[ContextProvider, str, list]):
+    def __init__(self, role: str, *initial_items: Union[ContextProvider, str, list, 'Message']):
         self.role = role
         processed_items = []
         for item in initial_items:
-            if isinstance(item, str):
-                # Check if the string contains placeholders from f-string rendering
+            if item is None:
+                continue
+
+            # This is the new recursive flattening logic
+            if isinstance(item, Message):
+                processed_items.extend(item.provider())
+            elif isinstance(item, str):
                 import re
                 placeholder_pattern = re.compile(r'(__provider_placeholder_[a-f0-9]{32}__)')
                 parts = placeholder_pattern.split(item)
-
-                if len(parts) > 1: # Placeholders were found
+                if len(parts) > 1:
                     for part in parts:
                         if not part: continue
                         if placeholder_pattern.match(part):
@@ -330,18 +416,14 @@ class Message(ABC):
                                 processed_items.append(provider)
                         else:
                             processed_items.append(Texts(text=part))
-                else: # No placeholders, just a regular string
+                else:
                     processed_items.append(Texts(text=item))
-
-            elif isinstance(item, Message):
-                processed_items.extend(item.provider())
             elif isinstance(item, ContextProvider):
                 processed_items.append(item)
             elif isinstance(item, list):
                 for sub_item in item:
                     if not isinstance(sub_item, dict) or 'type' not in sub_item:
                         raise ValueError("List items must be dicts with a 'type' key.")
-
                     item_type = sub_item['type']
                     if item_type == 'text':
                         processed_items.append(Texts(text=sub_item.get('text', '')))
@@ -351,8 +433,16 @@ class Message(ABC):
                             processed_items.append(Images(url=image_url))
                     else:
                         raise ValueError(f"Unsupported item type in list: {item_type}")
+            elif isinstance(item, dict):
+                item_type = item.get('type')
+                if item_type == 'image_url':
+                    image_url = item.get('image_url', {}).get('url')
+                    if image_url:
+                        processed_items.append(Images(url=image_url))
+                else:
+                    raise ValueError(f"Unsupported dict item type: {item_type}")
             else:
-                raise TypeError(f"Unsupported item type: {type(item)}. Must be str, ContextProvider, or list.")
+                raise TypeError(f"Unsupported item type: {type(item)}. Must be str, ContextProvider, list, or dict.")
         self._items: List[ContextProvider] = processed_items
         self._parent_messages: Optional['Messages'] = None
 
@@ -371,8 +461,11 @@ class Message(ABC):
         for item in self._items:
             block = item.get_content_block()
             if block and block.content is not None:
+                # Check if it's a Texts provider with newline=True
+                # and it's not the very first item with content.
+                if isinstance(item, Texts) and hasattr(item, 'newline') and item.newline and final_parts:
+                    final_parts.append("\n\n")
                 final_parts.append(block.content)
-
         return "".join(final_parts)
 
     def pop(self, name: str) -> Optional[ContextProvider]:
@@ -466,11 +559,64 @@ class Message(ABC):
         # and our custom __eq__ on ContextProvider handles the comparison logic.
         return item in self._items
 
+    def has(self, provider_type: type) -> bool:
+        """Checks if the message contains a provider of a specific type."""
+        if not isinstance(provider_type, type) or not issubclass(provider_type, ContextProvider):
+            raise TypeError("provider_type must be a subclass of ContextProvider")
+        return any(isinstance(p, provider_type) for p in self._items)
+
+    def lstrip(self, provider_type: type):
+        """
+        从消息的左侧（开头）移除所有指定类型的 provider。
+        移除操作会一直持续，直到遇到一个不同类型的 provider 为止。
+        """
+        while self._items and type(self._items[0]) is provider_type:
+            self.pop(self._items[0].name)
+
+    def rstrip(self, provider_type: type):
+        """
+        从消息的右侧（末尾）移除所有指定类型的 provider。
+        移除操作会一直持续，直到遇到一个不同类型的 provider 为止。
+        """
+        while self._items and type(self._items[-1]) is provider_type:
+            self.pop(self._items[-1].name)
+
+    def strip(self, provider_type: type):
+        """
+        从消息的两侧移除所有指定类型的 provider。
+        """
+        self.lstrip(provider_type)
+        self.rstrip(provider_type)
+
     def __bool__(self) -> bool:
         return bool(self._items)
     def get(self, key: str, default: Any = None) -> Any:
         """提供类似字典的 .get() 方法来访问属性。"""
         return getattr(self, key, default)
+
+    async def refresh(self):
+        """刷新此消息中的所有 provider。"""
+        tasks = [provider.refresh() for provider in self._items]
+        await asyncio.gather(*tasks)
+
+    async def render(self) -> Optional[Dict[str, Any]]:
+        """
+        渲染消息为字典。首次调用时会隐式刷新以确保动态内容被加载。
+        后续调用将返回缓存版本，除非手动调用了 refresh()。
+        """
+        # 检查是否是首次渲染
+        is_first_render = not all(hasattr(p, '_cached_content') and p._cached_content is not None for p in self._items if p._is_stale)
+
+        if is_first_render:
+            await self.refresh()
+
+        return self.to_dict()
+
+    async def render_latest(self) -> Optional[Dict[str, Any]]:
+        """始终刷新并返回最新的渲染结果。"""
+        await self.refresh()
+        return self.to_dict()
+
     def to_dict(self) -> Optional[Dict[str, Any]]:
         is_multimodal = any(isinstance(p, Images) for p in self._items)
 
@@ -541,12 +687,20 @@ class ToolCalls(Message):
 
 class ToolResults(Message):
     """Represents a tool message with the result of a single tool call."""
-    def __init__(self, tool_call_id: str, content: str):
-        # We pass a Texts provider to the parent so it can be rendered,
-        # but the primary way to access content for ToolResults is via its dict representation.
-        super().__init__("tool", Texts(text=content))
+    def __init__(self, tool_call_id: str, content: Union[str, Message]):
+        # The base Message class now handles the absorption of a Message object.
+        # We just need to pass the content to the parent __init__.
+        # For ToolResults, we primarily care about the textual content.
+        if isinstance(content, Message):
+             # Extract only text-like providers to pass to the parent
+            text_providers = [p for p in content.provider() if not isinstance(p, Images)]
+            super().__init__("tool", *text_providers)
+        else:
+            super().__init__("tool", content)
+
         self.tool_call_id = tool_call_id
-        self._content = content
+        # After initialization, render the content to a simple string for _content.
+        self._content = self._render_content()
 
     def to_dict(self) -> Dict[str, Any]:
         return {
@@ -634,7 +788,27 @@ class Messages:
 
     def render(self) -> List[Dict[str, Any]]:
         results = [msg.to_dict() for msg in self._messages]
-        return [res for res in results if res]
+        non_empty_results = [res for res in results if res]
+
+        if not non_empty_results:
+            return []
+
+        merged_results = [non_empty_results[0]]
+        for i in range(1, len(non_empty_results)):
+            current_msg = non_empty_results[i]
+            last_merged_msg = merged_results[-1]
+
+            # Merge if roles match, no tool_calls, and content is string
+            if (current_msg.get('role') == last_merged_msg.get('role') and
+                'tool_calls' not in current_msg and
+                'tool_calls' not in last_merged_msg and
+                isinstance(current_msg.get('content'), str) and
+                isinstance(last_merged_msg.get('content'), str)):
+                last_merged_msg['content'] += current_msg.get('content', '')
+            else:
+                merged_results.append(current_msg)
+
+        return merged_results
 
     async def render_latest(self) -> List[Dict[str, Any]]:
         await self.refresh()
@@ -726,7 +900,8 @@ class Messages:
 
     def __len__(self) -> int: return len(self._messages)
     def __iter__(self): return iter(self._messages)
-
+    def __repr__(self):
+        return f"Messages({repr(self._messages)})"
     def __contains__(self, item: Any) -> bool:
         """Checks if a Message or ContextProvider is in the collection."""
         if isinstance(item, Message):
