@@ -9,7 +9,7 @@ sys.path.insert(0, os.path.abspath(os.path.join(os.path.dirname(__file__), '..')
 
 
 from architext import *
-
+from typing import Optional, Union, Callable
 # ==============================================================================
 # 单元测试部分
 # ==============================================================================
@@ -1709,6 +1709,228 @@ Files: {Files(visible=True, name="files")}
         rendered_tool_2 = await tool_results_msg.render()
         self.assertEqual(rendered_tool_1, rendered_tool_2)
 
+    async def test_zag_iadd_on_provider(self):
+        """测试对 provider 使用 += 操作符来追加文本"""
+        class Goal(Texts):
+            def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: str = "goal"):
+                super().__init__(text=text, name=name)
+
+            async def render(self) -> Optional[str]:
+                content = await super().render()
+                if content is None:
+                    return None
+                return f"<goal>{content}</goal>"
+
+        messages = Messages(UserMessage(Goal("hi")))
+
+        # This is the new syntax we want to test
+        goal_provider = messages.provider("goal")
+        goal_provider += "test"
+
+        rendered = await messages.render_latest()
+
+        self.assertEqual(len(rendered), 1)
+        self.assertEqual(rendered[0]['content'], "<goal>hitest</goal>")
+
+    async def test_zz_user_message_auto_merging(self):
+        """测试连续的UserMessage是否能自动合并"""
+        # 场景1: 初始化时合并
+        messages_init = Messages(UserMessage("hi"), UserMessage("hi2"))
+        self.assertEqual(len(messages_init), 1, "初始化时，两个连续的UserMessage应该合并为一个")
+        self.assertEqual(len(messages_init[0]), 2, "合并后的UserMessage应该包含两个Texts provider")
+
+        rendered_init = await messages_init.render_latest()
+        self.assertEqual(rendered_init[0]['content'], "hihi2", "合并后渲染的内容不正确")
+
+        # 场景2: 追加时合并
+        messages_append = Messages(UserMessage("hi"))
+        messages_append.append(UserMessage("hi2"))
+        self.assertEqual(len(messages_append), 1, "追加时，两个连续的UserMessage应该合并为一个")
+        self.assertEqual(len(messages_append[0]), 2, "追加合并后的UserMessage应该包含两个Texts provider")
+
+        rendered_append = await messages_append.render_latest()
+        self.assertEqual(rendered_append[0]['content'], "hihi2", "追加合并后渲染的内容不正确")
+
+        # 场景3: 追加RoleMessage时合并
+        messages_append.append(RoleMessage("user", "hi3"))
+        self.assertEqual(len(messages_append), 1, "追加RoleMessage时，连续的UserMessage应该合并为一个")
+        self.assertEqual(len(messages_append[0]), 3, "追加RoleMessage合并后的UserMessage应该包含三个Texts provider")
+
+        rendered_append_role = await messages_append.render_latest()
+        self.assertEqual(rendered_append_role[0]['content'], "hihi2hi3", "追加RoleMessage合并后渲染的内容不正确")
+
+        # 场景4: 追加包含ContextProvider和字符串组合的RoleMessage时合并
+        class Goal(Texts):
+            def __init__(self, text: Optional[Union[str, Callable[[], str]]] = None, name: str = "goal", visible: bool = True, newline: bool = False):
+                super().__init__(text=text, name=name, visible=visible, newline=newline)
+
+            async def render(self) -> Optional[str]:
+                content = await super().render()
+                if content is None:
+                    return None
+                return f"<goal>{content}</goal>"
+
+        messages_append.append(RoleMessage("user", Goal("goal") + "hi4"))
+        self.assertEqual(len(messages_append), 1, "追加(ContextProvider + str)的RoleMessage时，未能正确合并")
+        self.assertEqual(len(messages_append[0]), 4, "追加(ContextProvider + str)的RoleMessage合并后的provider数量不正确")
+
+        rendered_append_combo = await messages_append.render_latest()
+        self.assertEqual(rendered_append_combo[0]['content'], "hihi2hi3<goal>goalhi4</goal>", "追加(ContextProvider + str)合并后渲染的内容不正确")
+
+        # 场景5: 被空消息隔开的同角色消息在渲染时合并
+        messages_separated = Messages(UserMessage("hi"), AssistantMessage(""), UserMessage("hi2"))
+        rendered_separated = await messages_separated.render_latest()
+        self.assertEqual(len(rendered_separated), 1, "被空消息隔开的同角色消息在渲染时应该合并")
+        self.assertEqual(rendered_separated[0]['content'], "hihi2", "被空消息隔开的同角色消息合并后内容不正确")
+
+    async def test_zzc_files_update_with_head(self):
+        """测试 Files.update 是否支持 head 参数以及新的 refresh 逻辑"""
+        test_file = "test_file_head.txt"
+        file_content = "Line 1\nLine 2\nLine 3\nLine 4\nLine 5"
+        with open(test_file, "w", encoding='utf-8') as f:
+            f.write(file_content)
+
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+
+            # 1. Test update with head=3 using the provider from Messages
+            files_provider = messages.provider("files")
+            self.assertIsInstance(files_provider, Files)
+            files_provider.update(path=test_file, head=3)
+
+            rendered_head = await messages.render_latest()
+            expected_head_content = "Line 1\nLine 2\nLine 3"
+            self.assertIn(f"<file_content>{expected_head_content}</file_content>", rendered_head[0]['content'])
+            self.assertNotIn("Line 4", rendered_head[0]['content'])
+
+            # 2. Test update without head (default behavior)
+            files_provider.update(path=test_file)
+            rendered_full = await messages.render_latest()
+            self.assertIn(f"<file_content>{file_content}</file_content>", rendered_full[0]['content'])
+
+            # 3. Test that refresh overwrites manual content when file exists
+            files_provider.update(path=test_file, content="manual content")
+            rendered_overwritten = await messages.render_latest()
+            self.assertIn(f"<file_content>{file_content}</file_content>", rendered_overwritten[0]['content'])
+            self.assertNotIn("manual content", rendered_overwritten[0]['content'])
+
+            # 4. Test that manual content is kept if file does not exist
+            non_existent_file = "non_existent_for_sure.txt"
+            files_provider.update(path=non_existent_file, content="manual content to keep")
+            rendered_kept = await messages.render_latest()
+            self.assertIn("<file_content>manual content to keep</file_content>", rendered_kept[0]['content'])
+
+        finally:
+            if os.path.exists(test_file):
+                os.remove(test_file)
+
+    async def test_zzd_files_update_with_string_head(self):
+        """测试 Files.update 是否能自动将字符串 head 参数转换为整数"""
+        test_file = "test_file_string_head.txt"
+        file_content = "Line 1\nLine 2\nLine 3\nLine 4\nLine 5"
+        with open(test_file, "w", encoding='utf-8') as f:
+            f.write(file_content)
+
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+
+            # Test update with head="3"
+            files_provider = messages.provider("files")
+            self.assertIsInstance(files_provider, Files)
+            # This is the part that will likely fail before implementation
+            files_provider.update(path=test_file, head="3")
+
+            rendered_head = await messages.render_latest()
+            expected_head_content = "Line 1\nLine 2\nLine 3"
+            self.assertIn(f"<file_content>{expected_head_content}</file_content>", rendered_head[0]['content'])
+            self.assertNotIn("Line 4", rendered_head[0]['content'])
+
+        finally:
+            if os.path.exists(test_file):
+                os.remove(test_file)
+
+    async def test_zzc_files_update_with_head_and_content(self):
+        """测试update同时设置path, content, head时的行为"""
+        existing_file = "test_file_existing.txt"
+        non_existent_file = "test_file_non_existent.txt"
+        existing_content = "Line 1 (from file)\nLine 2 (from file)\nLine 3 (from file)\nLine 4 (from file)"
+        manual_content = "Line 1 (manual)\nLine 2 (manual)\nLine 3 (manual)\nLine 4 (manual)"
+
+        # --- 场景1: 文件存在 ---
+        with open(existing_file, "w", encoding='utf-8') as f:
+            f.write(existing_content)
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+            files_provider = messages.provider("files")
+            files_provider.update(path=existing_file, content=manual_content, head=2)
+            rendered_existing = await messages.render_latest()
+            expected_existing_head = "Line 1 (from file)\nLine 2 (from file)"
+            self.assertIn(f"<file_content>{expected_existing_head}</file_content>", rendered_existing[0]['content'])
+            self.assertNotIn("manual", rendered_existing[0]['content'])
+        finally:
+            if os.path.exists(existing_file):
+                os.remove(existing_file)
+
+        # --- 场景2: 文件不存在 ---
+        try:
+            messages = Messages(UserMessage(Files(name="files")))
+            files_provider = messages.provider("files")
+            files_provider.update(path=non_existent_file, content=manual_content, head=2)
+            rendered_non_existent = await messages.render_latest()
+            expected_manual_head = "Line 1 (manual)\nLine 2 (manual)"
+            self.assertIn(f"<file_content>{expected_manual_head}</file_content>", rendered_non_existent[0]['content'])
+            self.assertNotIn("from file", rendered_non_existent[0]['content'])
+        finally:
+            if os.path.exists(non_existent_file):
+                os.remove(non_existent_file)
+
+    async def test_auto_convert_image_dict_to_image_provider(self):
+        """测试 UserMessage 是否能自动转换 image_url 字典为 Images provider"""
+        base64_image_data = "/9j/4AAQSkZJRgABAQEAYABgAAD/4QAiRXhpZgAATU0AKgAAAAgAAQESAAMAAAABAAEAAAAAAAD/2wBDAAIBAQIBAQICAgICAgICAwUDAwMDAwYEBAMFBwYHBwcGBwcICQsJCAgKCAcHCg0KCgsMDAwMBwkODw0MDgsMDAz/2wBDAQICAgMDAwYDAwYMCAcIDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAwMDAz/wAARCAABAAEDASIAAhEBAxEB/8QAHwAAAQUBAQEBAQEAAAAAAAAAAAECAwQFBgcICQoL/8QAtRAAAgEDAwIEAwUFBAQAAAF9AQIDAAQRBRIhMUEGE1FhByJxFDKBkaEII0KxwRVS0fAkM2JyggkKFhcYGRolJicoKSo0NTY3ODk6Q0RFRkdISUpTVFVWV1hZWmNkZWZnaGlqc3R1dnd4eXqDhIWGh4iJipKTlJWWl5iZmqKjpKWmp6ipqrKztLW2t7i5usLDxMXGx8jJytLT1NXW19jZ2uHi4+Tl5ufo6erx8vP09fb3+Pn6/8QAHwEAAwEBAQEBAQEBAQAAAAAAAAECAwQFBgcICQoL/8QAtREAAgECBAQDBAcFBAQAAQJ3AAECAxEEBSExBhJBUQdhcRMiMoEIFEKRobHBCSMzUvAVYnLRChYkNOEl8RcYGRomJygpKjU2Nzg5OkNERUZHSElKU1RVVldYWVpjZGVmZ2hpanN0dXZ3eHl6goOEhYaHiImKkpOUlZaXmJmaoqOkpaanqKmqsrO0tba3uLm6wsPExcbHyMnK0tPU1dbX2Nna4uPk5ebn6Onq8vP09fb3+Pn6/9oADAMBAAIRAxEAPwD9/KKKKAP/2Q=="
+        image_dict = {
+            'type': 'image_url',
+            'image_url': {
+                'url': f'data:image/jpeg;base64,{base64_image_data}'
+            }
+        }
+
+        # This is the functionality we are testing.
+        # The UserMessage should be able to take this dictionary directly.
+        message = UserMessage(image_dict)
+
+        # 1. Verify that the message contains exactly one provider.
+        self.assertEqual(len(message.provider()), 1)
+
+        # 2. Verify that the provider is an instance of the Images class.
+        image_provider = message.provider()[0]
+        self.assertIsInstance(image_provider, Images)
+
+        # 3. Verify that the content of the Images provider is correct.
+        rendered = await message.render_latest()
+        self.assertEqual(rendered['content'][0]['image_url']['url'], image_dict['image_url']['url'])
+
+    async def test_zzd_texts_cache_control(self):
+        """测试 Texts provider deepcopy in relation to dynamic content"""
+        import copy
+        counter = 0
+        def dynamic_content():
+            nonlocal counter
+            counter += 1
+            return str(counter)
+
+        # When a message with a dynamic provider is deep-copied,
+        # the dynamic nature (the callable) should be preserved.
+        counter = 0
+        # provider_in_fstring = f"{Texts(lambda: dynamic_content())}"
+        provider_in_fstring = f"{Texts(dynamic_content)}"
+        messages_copied = copy.deepcopy(Messages(UserMessage(provider_in_fstring)))
+
+        # Each call to render_latest() should re-evaluate the dynamic content.
+        await messages_copied.render_latest()
+        await messages_copied.render_latest()
+        await messages_copied.render_latest()
+        self.assertEqual(counter, 3, "Dynamic function should be re-evaluated on each render_latest call")
+
 
 # ==============================================================================
 # 6. 演示
