@@ -1,13 +1,24 @@
 import re
 import json
 import copy
+import hmac
+import time
 import httpx
 import base64
 import asyncio
+import hashlib
+import datetime
+import urllib.parse
 from io import IOBase
 from typing import Tuple
+from datetime import timezone
 from urllib.parse import urlparse
 
+
+from cryptography.hazmat.primitives import hashes
+from cryptography.hazmat.primitives.asymmetric import padding
+from cryptography.hazmat.primitives.serialization import load_pem_private_key
+
 from .models import RequestModel, Message
 from .utils import (
     c3s,
@@ -16,7 +27,7 @@ from .utils import (
     c35s,
     c4,
     gemini1,
-    gemini2,
+    gemini_preview,
     gemini2_5_pro_exp,
     BaseAPI,
     safe_get,
@@ -57,7 +68,7 @@ async def get_gemini_payload(request, engine, provider, api_key=None):
 
     try:
         request_messages = [Message(role="user", content=request.prompt)]
-    except:
+    except Exception:
         request_messages = copy.deepcopy(request.messages)
     for msg in request_messages:
         if msg.role == "assistant":
@@ -295,16 +306,11 @@ async def get_gemini_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude", "deepseek"]) and "-" not in key:
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
 
-import time
-from cryptography.hazmat.primitives import hashes
-from cryptography.hazmat.primitives.asymmetric import padding
-from cryptography.hazmat.primitives.serialization import load_pem_private_key
-
 def create_jwt(client_email, private_key):
     # JWT Header
     header = json.dumps({
@@ -375,12 +381,14 @@ async def get_vertex_gemini_payload(request, engine, provider, api_key=None):
 
     # https://cloud.google.com/vertex-ai/generative-ai/docs/models/gemini/2-0-flash?hl=zh-cn
     pro_models = ["gemini-2.5"]
-    if any(pro_model in original_model for pro_model in pro_models):
+    if "gemini-2.5-flash-image-preview" in original_model:
+        location = gemini_preview
+    elif any(pro_model in original_model for pro_model in pro_models):
         location = gemini2_5_pro_exp
     else:
         location = gemini1
 
-    if "google-vertex-ai" in provider.get("base_url", ""):
+    if "google-vertex-ai" in provider.get("base_url", "") or "gemini-2.5-flash-image-preview" in original_model:
         url = provider.get("base_url").rstrip('/') + "/v1/projects/{PROJECT_ID}/locations/{LOCATION}/publishers/google/models/{MODEL_ID}:{stream}".format(
             LOCATION=await location.next(),
             PROJECT_ID=project_id,
@@ -591,7 +599,7 @@ async def get_vertex_gemini_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude"]):
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
@@ -608,7 +616,7 @@ async def get_vertex_claude_payload(request, engine, provider, api_key=None):
 
     model_dict = get_model_dict(provider)
     original_model = model_dict[request.model]
-    if "claude-3-5-sonnet" in original_model or "claude-3-7-sonnet" in original_model:
+    if "claude-3-5-sonnet" in original_model or "claude-3-7-sonnet" in original_model or "4-5@" in original_model:
         location = c35s
     elif "claude-3-opus" in original_model:
         location = c3o
@@ -754,18 +762,12 @@ async def get_vertex_claude_payload(request, engine, provider, api_key=None):
                         "type": "any"
                     }
 
-    if provider.get("tools") == False:
+    if provider.get("tools") is False:
         payload.pop("tools", None)
         payload.pop("tool_choice", None)
 
     return url, headers, payload
 
-import hashlib
-import hmac
-import datetime
-import urllib.parse
-from datetime import timezone
-
 def sign(key, msg):
     return hmac.new(key, msg.encode('utf-8'), hashlib.sha256).digest()
 
@@ -837,7 +839,7 @@ async def get_aws_payload(request, engine, provider, api_key=None):
     url = f"{base_url}/model/{original_model}/invoke-with-response-stream"
 
     messages = []
-    system_prompt = None
+    # system_prompt = None
     tool_id = None
     for msg in request.messages:
         tool_call_id = None
@@ -887,8 +889,8 @@ async def get_aws_payload(request, engine, provider, api_key=None):
             }]})
         elif msg.role != "system":
             messages.append({"role": msg.role, "content": content})
-        elif msg.role == "system":
-            system_prompt = content
+        # elif msg.role == "system":
+        #     system_prompt = content
 
     conversation_len = len(messages) - 1
     message_index = 0
@@ -971,7 +973,7 @@ async def get_aws_payload(request, engine, provider, api_key=None):
                         "type": "any"
                     }
 
-    if provider.get("tools") == False:
+    if provider.get("tools") is False:
         payload.pop("tools", None)
         payload.pop("tool_choice", None)
 
@@ -1015,9 +1017,16 @@ async def get_gpt_payload(request, engine, provider, api_key=None):
             for item in msg.content:
                 if item.type == "text":
                     text_message = await get_text_message(item.text, engine)
+                    if "v1/responses" in url:
+                        text_message["type"] = "input_text"
                     content.append(text_message)
                 elif item.type == "image_url" and provider.get("image", True) and "o1-mini" not in original_model:
                     image_message = await get_image_message(item.image_url.url, engine)
+                    if "v1/responses" in url:
+                        image_message = {
+                            "type": "input_image",
+                            "image_url": image_message["image_url"]["url"]
+                        }
                     content.append(image_message)
         else:
             content = msg.content
@@ -1049,10 +1058,16 @@ async def get_gpt_payload(request, engine, provider, api_key=None):
         system_msg = messages.pop(0)
         messages[0]["content"] = system_msg["content"] + messages[0]["content"]
 
-    payload = {
-        "model": original_model,
-        "messages": messages,
-    }
+    if "v1/responses" in url:
+        payload = {
+            "model": original_model,
+            "input": messages,
+        }
+    else:
+        payload = {
+            "model": original_model,
+            "messages": messages,
+        }
 
     miss_fields = [
         'model',
@@ -1066,7 +1081,7 @@ async def get_gpt_payload(request, engine, provider, api_key=None):
             else:
                 payload[field] = value
 
-    if provider.get("tools") == False or "o1-mini" in original_model or "chatgpt-4o-latest" in original_model or "grok" in original_model:
+    if provider.get("tools") is False or "o1-mini" in original_model or "chatgpt-4o-latest" in original_model or "grok" in original_model:
         payload.pop("tools", None)
         payload.pop("tool_choice", None)
 
@@ -1085,15 +1100,27 @@ async def get_gpt_payload(request, engine, provider, api_key=None):
     "o3" in original_model or "o4" in original_model or \
     "gpt-oss" in original_model or "gpt-5" in original_model:
         if request.model.endswith("high"):
-            payload["reasoning_effort"] = "high"
+            if "v1/responses" in url:
+                payload["reasoning"] = {"effort": "high"}
+            else:
+                payload["reasoning_effort"] = "high"
         elif request.model.endswith("low"):
-            payload["reasoning_effort"] = "low"
-        else:
-            payload["reasoning_effort"] = "medium"
+            if "v1/responses" in url:
+                payload["reasoning"] = {"effort": "low"}
+            else:
+                payload["reasoning_effort"] = "low"
+        # else:
+        #     if "v1/responses" in url:
+        #         payload["reasoning"] = {"effort": "medium"}
+        #     else:
+        #         payload["reasoning_effort"] = "medium"
 
         if "temperature" in payload:
             payload.pop("temperature")
 
+        if "v1/responses" in url:
+            payload.pop("stream_options", None)
+
     # 代码生成/数学解题  0.0
     # 数据抽取/分析	     1.0
     # 通用对话          1.3
@@ -1127,7 +1154,7 @@ async def get_gpt_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude"]):
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
@@ -1216,7 +1243,7 @@ async def get_azure_payload(request, engine, provider, api_key=None):
             else:
                 payload[field] = value
 
-    if provider.get("tools") == False or "o1" in original_model or "chatgpt-4o-latest" in original_model or "grok" in original_model:
+    if provider.get("tools") is False or "o1" in original_model or "chatgpt-4o-latest" in original_model or "grok" in original_model:
         payload.pop("tools", None)
         payload.pop("tool_choice", None)
 
@@ -1225,7 +1252,7 @@ async def get_azure_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude"]):
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
@@ -1311,7 +1338,7 @@ async def get_azure_databricks_payload(request, engine, provider, api_key=None):
             else:
                 payload[field] = value
 
-    if provider.get("tools") == False or "o1" in original_model or "chatgpt-4o-latest" in original_model or "grok" in original_model:
+    if provider.get("tools") is False or "o1" in original_model or "chatgpt-4o-latest" in original_model or "grok" in original_model:
         payload.pop("tools", None)
         payload.pop("tool_choice", None)
 
@@ -1345,7 +1372,7 @@ async def get_azure_databricks_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude"]):
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
@@ -1432,7 +1459,7 @@ async def get_openrouter_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude"]):
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
@@ -1601,7 +1628,7 @@ async def gpt2claude_tools_json(json_dict):
     for old_key, new_key in keys_to_change.items():
         if old_key in json_dict:
             if new_key:
-                if json_dict[old_key] == None:
+                if json_dict[old_key] is None:
                     json_dict[old_key] = {
                         "type": "object",
                         "properties": {}
@@ -1763,7 +1790,7 @@ async def get_claude_payload(request, engine, provider, api_key=None):
                         "type": "any"
                     }
 
-    if provider.get("tools") == False:
+    if provider.get("tools") is False:
         payload.pop("tools", None)
         payload.pop("tool_choice", None)
 
@@ -1798,7 +1825,7 @@ async def get_claude_payload(request, engine, provider, api_key=None):
             if key == request.model:
                 for k, v in value.items():
                     payload[k] = v
-            elif all(_model not in request.model.lower() for _model in ["gemini", "gpt", "claude"]):
+            elif all(_model not in request.model.lower() for _model in model_dict.keys()) and "-" not in key and " " not in key:
                 payload[key] = value
 
     return url, headers, payload
@@ -1843,8 +1870,6 @@ async def get_upload_certificate(client: httpx.AsyncClient, api_key: str, model:
         print(f"获取凭证时发生未知错误: {e}")
         return None
 
-from mimetypes import guess_type
-
 async def upload_file_to_oss(client: httpx.AsyncClient, certificate: dict, file: Tuple[str, IOBase, str]) -> str:
     """第二步：使用凭证将文件内容上传到OSS"""
     upload_host = certificate.get("upload_host")
