@@ -8,7 +8,7 @@ from datetime import datetime
 
 from .log_config import logger
 
-from .utils import safe_get, generate_sse_response, generate_no_stream_response, end_of_line, parse_json_safely
+from .utils import safe_get, generate_sse_response, generate_no_stream_response, end_of_line, parse_json_safely, upload_image_to_0x0st
 
 async def check_response(response, error_log):
     if response and not (200 <= response.status_code < 300):
@@ -21,13 +21,12 @@ async def check_response(response, error_log):
         return {"error": f"{error_log} HTTP Error", "status_code": response.status_code, "details": error_json}
     return None
 
-async def gemini_json_poccess(response_str):
+async def gemini_json_poccess(response_json):
     promptTokenCount = 0
     candidatesTokenCount = 0
     totalTokenCount = 0
     image_base64 = None
 
-    response_json = await asyncio.to_thread(json.loads, response_str)
     json_data = safe_get(response_json, "candidates", 0, "content", default=None)
     finishReason = safe_get(response_json, "candidates", 0 , "finishReason", default=None)
     if finishReason:
@@ -46,9 +45,9 @@ async def gemini_json_poccess(response_str):
     if is_thinking:
         content = safe_get(json_data, "parts", 1, "text", default="")
 
-    function_call_name = safe_get(json_data, "functionCall", "name", default=None)
-    function_full_response = safe_get(json_data, "functionCall", "args", default="")
-    function_full_response = json.dumps(function_full_response) if function_full_response else None
+    function_call_name = safe_get(json_data, "parts", 0, "functionCall", "name", default=None)
+    function_full_response = safe_get(json_data, "parts", 0, "functionCall", "args", default="")
+    function_full_response = await asyncio.to_thread(json.dumps, function_full_response) if function_full_response else None
 
     blockReason = safe_get(json_data, 0, "promptFeedback", "blockReason", default=None)
 
@@ -56,7 +55,8 @@ async def gemini_json_poccess(response_str):
 
 async def fetch_gemini_response_stream(client, url, headers, payload, model, timeout):
     timestamp = int(datetime.timestamp(datetime.now()))
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_gemini_response_stream")
         if error_message:
             yield error_message
@@ -76,20 +76,20 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model, tim
                 if line.startswith("data: "):
                     parts_json = line.lstrip("data: ").strip()
                     try:
-                        await asyncio.to_thread(json.loads, parts_json)
+                        response_json = await asyncio.to_thread(json.loads, parts_json)
                     except json.JSONDecodeError:
-                        logger.error(f"JSON decode error: {parts_json}")
+                        # logger.error(f"JSON decode error: {parts_json}")
                         continue
                 else:
                     parts_json += line
                     parts_json = parts_json.lstrip("[,")
                     try:
-                        await asyncio.to_thread(json.loads, parts_json)
+                        response_json = await asyncio.to_thread(json.loads, parts_json)
                     except json.JSONDecodeError:
                         continue
 
                 # https://ai.google.dev/api/generate-content?hl=zh-cn#FinishReason
-                is_thinking, reasoning_content, content, image_base64, function_call_name, function_full_response, finishReason, blockReason, promptTokenCount, candidatesTokenCount, totalTokenCount = await gemini_json_poccess(parts_json)
+                is_thinking, reasoning_content, content, image_base64, function_call_name, function_full_response, finishReason, blockReason, promptTokenCount, candidatesTokenCount, totalTokenCount = await gemini_json_poccess(response_json)
 
                 if is_thinking:
                     sse_string = await generate_sse_response(timestamp, model, reasoning_content=reasoning_content)
@@ -99,7 +99,12 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model, tim
                     yield sse_string
 
                 if image_base64:
-                    yield await generate_no_stream_response(timestamp, model, content=content, tools_id=None, function_call_name=None, function_call_content=None, role=None, total_tokens=totalTokenCount, prompt_tokens=promptTokenCount, completion_tokens=candidatesTokenCount, image_base64=image_base64)
+                    if "gemini-2.5-flash-image" not in model:
+                        yield await generate_no_stream_response(timestamp, model, content=content, tools_id=None, function_call_name=None, function_call_content=None, role=None, total_tokens=totalTokenCount, prompt_tokens=promptTokenCount, completion_tokens=candidatesTokenCount, image_base64=image_base64)
+                    else:
+                        image_url = await upload_image_to_0x0st("data:image/png;base64," + image_base64)
+                        sse_string = await generate_sse_response(timestamp, model, content=f"\n\n![image]({image_url})")
+                        yield sse_string
 
                 if function_call_name:
                     sse_string = await generate_sse_response(timestamp, model, content=None, tools_id="chatcmpl-9inWv0yEtgn873CxMBzHeCeiHctTV", function_call_name=function_call_name)
@@ -125,7 +130,8 @@ async def fetch_gemini_response_stream(client, url, headers, payload, model, tim
 
 async def fetch_vertex_claude_response_stream(client, url, headers, payload, model, timeout):
     timestamp = int(datetime.timestamp(datetime.now()))
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_vertex_claude_response_stream")
         if error_message:
             yield error_message
@@ -182,7 +188,7 @@ async def fetch_vertex_claude_response_stream(client, url, headers, payload, mod
             function_call_id = function_call["id"]
             sse_string = await generate_sse_response(timestamp, model, content=None, tools_id=function_call_id, function_call_name=function_call_name)
             yield sse_string
-            function_full_response = json.dumps(function_call["input"])
+            function_full_response = await asyncio.to_thread(json.dumps, function_call["input"])
             sse_string = await generate_sse_response(timestamp, model, content=None, tools_id=function_call_id, function_call_name=None, function_call_content=function_full_response)
             yield sse_string
 
@@ -198,7 +204,8 @@ async def fetch_gpt_response_stream(client, url, headers, payload, timeout):
     is_thinking = False
     has_send_thinking = False
     ark_tag = False
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_gpt_response_stream")
         if error_message:
             yield error_message
@@ -206,17 +213,44 @@ async def fetch_gpt_response_stream(client, url, headers, payload, timeout):
 
         buffer = ""
         enter_buffer = ""
+
+        input_tokens = 0
+        output_tokens = 0
+
         async for chunk in response.aiter_text():
             buffer += chunk
             while "\n" in buffer:
                 line, buffer = buffer.split("\n", 1)
                 # logger.info("line: %s", repr(line))
-                if line and not line.startswith(":") and (result:=line.lstrip("data: ").strip()):
+                if line.startswith(": keepalive"):
+                    yield line + end_of_line
+                    continue
+                if line and not line.startswith(":") and (result:=line.lstrip("data: ").strip()) and not line.startswith("event: "):
                     if result.strip() == "[DONE]":
                         break
                     line = await asyncio.to_thread(json.loads, result)
                     line['id'] = f"chatcmpl-{random_str}"
 
+                    # v1/responses
+                    if line.get("type") == "response.reasoning_summary_text.delta" and line.get("delta"):
+                        sse_string = await generate_sse_response(timestamp, payload["model"], reasoning_content=line.get("delta"))
+                        yield sse_string
+                        continue
+                    elif line.get("type") == "response.output_text.delta" and line.get("delta"):
+                        sse_string = await generate_sse_response(timestamp, payload["model"], content=line.get("delta"))
+                        yield sse_string
+                        continue
+                    elif line.get("type") == "response.output_text.done":
+                        sse_string = await generate_sse_response(timestamp, payload["model"], stop="stop")
+                        yield sse_string
+                        continue
+                    elif line.get("type") == "response.completed":
+                        input_tokens = safe_get(line, "response", "usage", "input_tokens", default=0)
+                        output_tokens = safe_get(line, "response", "usage", "output_tokens", default=0)
+                        continue
+                    elif line.get("type", "").startswith("response."):
+                        continue
+
                     # 处理 <think> 标签
                     content = safe_get(line, "choices", 0, "delta", "content", default="")
                     if "<think>" in content:
@@ -270,6 +304,12 @@ async def fetch_gpt_response_stream(client, url, headers, payload, timeout):
 
                     no_stream_content = safe_get(line, "choices", 0, "message", "content", default=None)
                     openrouter_reasoning = safe_get(line, "choices", 0, "delta", "reasoning", default="")
+                    openrouter_base64_image = safe_get(line, "choices", 0, "delta", "images", 0, "image_url", "url", default="")
+                    if openrouter_base64_image:
+                        image_url = await upload_image_to_0x0st(openrouter_base64_image)
+                        sse_string = await generate_sse_response(timestamp, payload["model"], content=f"\n\n![image]({image_url})")
+                        yield sse_string
+                        continue
                     azure_databricks_claude_summary_content = safe_get(line, "choices", 0, "delta", "content", 0, "summary", 0, "text", default="")
                     azure_databricks_claude_signature_content = safe_get(line, "choices", 0, "delta", "content", 0, "summary", 0, "signature", default="")
                     # print("openrouter_reasoning", repr(openrouter_reasoning), openrouter_reasoning.endswith("\\\\"), openrouter_reasoning.endswith("\\"))
@@ -304,7 +344,13 @@ async def fetch_gpt_response_stream(client, url, headers, payload, timeout):
                     else:
                         if no_stream_content:
                             del line["choices"][0]["message"]
-                        yield "data: " + json.dumps(line).strip() + end_of_line
+                        json_line = await asyncio.to_thread(json.dumps, line)
+                        yield "data: " + json_line.strip() + end_of_line
+
+    if input_tokens and output_tokens:
+        sse_string = await generate_sse_response(timestamp, payload["model"], None, None, None, None, None, total_tokens=input_tokens + output_tokens, prompt_tokens=input_tokens, completion_tokens=output_tokens)
+        yield sse_string
+
     yield "data: [DONE]" + end_of_line
 
 async def fetch_azure_response_stream(client, url, headers, payload, timeout):
@@ -312,7 +358,8 @@ async def fetch_azure_response_stream(client, url, headers, payload, timeout):
     is_thinking = False
     has_send_thinking = False
     ark_tag = False
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_azure_response_stream")
         if error_message:
             yield error_message
@@ -360,12 +407,14 @@ async def fetch_azure_response_stream(client, url, headers, payload, timeout):
                     else:
                         if no_stream_content:
                             del line["choices"][0]["message"]
-                        yield "data: " + json.dumps(line).strip() + end_of_line
+                        json_line = await asyncio.to_thread(json.dumps, line)
+                        yield "data: " + json_line.strip() + end_of_line
     yield "data: [DONE]" + end_of_line
 
 async def fetch_cloudflare_response_stream(client, url, headers, payload, model, timeout):
     timestamp = int(datetime.timestamp(datetime.now()))
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_cloudflare_response_stream")
         if error_message:
             yield error_message
@@ -390,7 +439,8 @@ async def fetch_cloudflare_response_stream(client, url, headers, payload, model,
 
 async def fetch_cohere_response_stream(client, url, headers, payload, model, timeout):
     timestamp = int(datetime.timestamp(datetime.now()))
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_cohere_response_stream")
         if error_message:
             yield error_message
@@ -413,7 +463,8 @@ async def fetch_cohere_response_stream(client, url, headers, payload, model, tim
 
 async def fetch_claude_response_stream(client, url, headers, payload, model, timeout):
     timestamp = int(datetime.timestamp(datetime.now()))
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_claude_response_stream")
         if error_message:
             yield error_message
@@ -466,7 +517,8 @@ async def fetch_claude_response_stream(client, url, headers, payload, model, tim
 
 async def fetch_aws_response_stream(client, url, headers, payload, model, timeout):
     timestamp = int(datetime.timestamp(datetime.now()))
-    async with client.stream('POST', url, headers=headers, json=payload, timeout=timeout) as response:
+    json_payload = await asyncio.to_thread(json.dumps, payload)
+    async with client.stream('POST', url, headers=headers, content=json_payload, timeout=timeout) as response:
         error_message = await check_response(response, "fetch_aws_response_stream")
         if error_message:
             yield error_message
@@ -521,7 +573,8 @@ async def fetch_response(client, url, headers, payload, engine, model, timeout=2
         file = payload.pop("file")
         response = await client.post(url, headers=headers, data=payload, files={"file": file}, timeout=timeout)
     else:
-        response = await client.post(url, headers=headers, json=payload, timeout=timeout)
+        json_payload = await asyncio.to_thread(json.dumps, payload)
+        response = await client.post(url, headers=headers, content=json_payload, timeout=timeout)
     error_message = await check_response(response, "fetch_response")
     if error_message:
         yield error_message
@@ -586,7 +639,7 @@ async def fetch_response(client, url, headers, payload, engine, model, timeout=2
         timestamp = int(datetime.timestamp(datetime.now()))
         yield await generate_no_stream_response(timestamp, model, content=content, tools_id=None, function_call_name=function_call_name, function_call_content=function_call_content, role=role, total_tokens=total_tokens, prompt_tokens=prompt_tokens, completion_tokens=candidates_tokens, reasoning_content=reasoning_content, image_base64=image_base64)
 
-    elif engine == "claude":
+    elif engine == "claude" or engine == "vertex-claude":
         response_bytes = await response.aread()
         response_json = await asyncio.to_thread(json.loads, response_bytes)
         # print("response_json", json.dumps(response_json, indent=4, ensure_ascii=False))
