@@ -4,12 +4,16 @@ import ast
 import json
 import httpx
 import base64
+import random
+import string
 import asyncio
+import traceback
 from time import time
 from PIL import Image
 from fastapi import HTTPException
-from urllib.parse import urlparse
 from collections import defaultdict
+from httpx_socks import AsyncProxyTransport
+from urllib.parse import urlparse, urlunparse
 
 from .log_config import logger
 
@@ -33,7 +37,6 @@ class BaseAPI:
         if api_url == "":
             api_url = "https://api.openai.com/v1/chat/completions"
         self.source_api_url: str = api_url
-        from urllib.parse import urlparse, urlunparse
         parsed_url = urlparse(self.source_api_url)
         # print("parsed_url", parsed_url)
         if parsed_url.scheme == "":
@@ -50,7 +53,11 @@ class BaseAPI:
             self.v1_models: str = urlunparse(parsed_url[:2] + ("v1/models",) + ("",) * 3)
         else:
             self.v1_models: str = urlunparse(parsed_url[:2] + (before_v1 + "models",) + ("",) * 3)
-        self.chat_url: str = urlunparse(parsed_url[:2] + (before_v1 + "chat/completions",) + ("",) * 3)
+
+        if "v1/responses" in parsed_url.path:
+            self.chat_url: str = api_url
+        else:
+            self.chat_url: str = urlunparse(parsed_url[:2] + (before_v1 + "chat/completions",) + ("",) * 3)
         self.image_url: str = urlunparse(parsed_url[:2] + (before_v1 + "images/generations",) + ("",) * 3)
         if parsed_url.hostname == "dashscope.aliyuncs.com":
             self.audio_transcriptions: str = urlunparse(parsed_url[:2] + ("/api/v1/services/aigc/multimodal-generation/generation",) + ("",) * 3)
@@ -148,7 +155,6 @@ def get_engine(provider, endpoint=None, original_model=""):
 
     return engine, stream
 
-from httpx_socks import AsyncProxyTransport
 def get_proxy(proxy, client_config = {}):
     if proxy:
         # 解析代理URL
@@ -219,16 +225,19 @@ async def update_initial_model(provider):
         models_id = list(set_models)
         # print(models_id)
         return models_id
-    except Exception as e:
-        # print("error:", e)
-        import traceback
+    except Exception:
         traceback.print_exc()
         return []
 
 def safe_get(data, *keys, default=None):
     for key in keys:
         try:
-            data = data[key] if isinstance(data, (dict, list)) else data.get(key)
+            if isinstance(data, (dict, list)):
+                data = data[key]
+            elif isinstance(key, str) and hasattr(data, key):
+                data = getattr(data, key)
+            else:
+                data = data.get(key)
         except (KeyError, IndexError, AttributeError, TypeError):
             return default
     if not data:
@@ -243,7 +252,8 @@ def parse_rate_limit(limit_string):
         'h': 3600, 'hr': 3600, 'hour': 3600,
         'd': 86400, 'day': 86400,
         'mo': 2592000, 'month': 2592000,
-        'y': 31536000, 'year': 31536000
+        'y': 31536000, 'year': 31536000,
+        'tpr': -1,
     }
 
     # 处理多个限制条件
@@ -268,27 +278,31 @@ def parse_rate_limit(limit_string):
     return limits
 
 class ThreadSafeCircularList:
-    def __init__(self, items = [], rate_limit={"default": "999999/min"}, schedule_algorithm="round_robin"):
+    def __init__(self, items = [], rate_limit={"default": "999999/min"}, schedule_algorithm="round_robin", provider_name=None):
+        self.provider_name = provider_name
+        self.original_items = list(items)
+        self.schedule_algorithm = schedule_algorithm
+
         if schedule_algorithm == "random":
-            import random
             self.items = random.sample(items, len(items))
-            self.schedule_algorithm = "random"
         elif schedule_algorithm == "round_robin":
             self.items = items
-            self.schedule_algorithm = "round_robin"
         elif schedule_algorithm == "fixed_priority":
             self.items = items
-            self.schedule_algorithm = "fixed_priority"
+        elif schedule_algorithm == "smart_round_robin":
+            self.items = items
         else:
             self.items = items
-            logger.warning(f"Unknown schedule algorithm: {schedule_algorithm}, use (round_robin, random, fixed_priority) instead")
+            logger.warning(f"Unknown schedule algorithm: {schedule_algorithm}, use (round_robin, random, fixed_priority, smart_round_robin) instead")
             self.schedule_algorithm = "round_robin"
+
         self.index = 0
         self.lock = asyncio.Lock()
-        # 修改为二级字典，第一级是item，第二级是model
         self.requests = defaultdict(lambda: defaultdict(list))
         self.cooling_until = defaultdict(float)
         self.rate_limits = {}
+        self.reordering_task = None
+
         if isinstance(rate_limit, dict):
             for rate_limit_model, rate_limit_value in rate_limit.items():
                 self.rate_limits[rate_limit_model] = parse_rate_limit(rate_limit_value)
@@ -297,6 +311,38 @@ class ThreadSafeCircularList:
         else:
             logger.error(f"Error ThreadSafeCircularList: Unknown rate_limit type: {type(rate_limit)}, rate_limit: {rate_limit}")
 
+        if self.schedule_algorithm == "smart_round_robin":
+            logger.info(f"Initializing '{self.provider_name}' with 'smart_round_robin' algorithm.")
+            self._trigger_reorder()
+
+    async def reset_items(self, new_items: list):
+        """Safely replaces the current list of items with a new one."""
+        async with self.lock:
+            if self.items != new_items:
+                self.items = new_items
+                self.index = 0
+                logger.info(f"Provider '{self.provider_name}' API key list has been reset and reordered.")
+
+    def _trigger_reorder(self):
+        """Asynchronously triggers the reordering task if not already running."""
+        if self.provider_name and (self.reordering_task is None or self.reordering_task.done()):
+            logger.info(f"Triggering reorder for provider '{self.provider_name}'...")
+            try:
+                loop = asyncio.get_running_loop()
+                self.reordering_task = loop.create_task(self._reorder_keys())
+            except RuntimeError:
+                logger.warning(f"No running event loop to trigger reorder for '{self.provider_name}'.")
+
+    async def _reorder_keys(self):
+        """Performs the actual reordering logic."""
+        from utils import get_sorted_api_keys
+        try:
+            sorted_keys = await get_sorted_api_keys(self.provider_name, self.original_items, group_size=100)
+            if sorted_keys:
+                await self.reset_items(sorted_keys)
+        except Exception as e:
+            logger.error(f"Error during key reordering for provider '{self.provider_name}': {e}")
+
     async def set_cooling(self, item: str, cooling_time: int = 60):
         """设置某个 item 进入冷却状态
 
@@ -304,7 +350,7 @@ class ThreadSafeCircularList:
             item: 需要冷却的 item
             cooling_time: 冷却时间(秒)，默认60秒
         """
-        if item == None:
+        if item is None:
             return
         now = time()
         async with self.lock:
@@ -364,6 +410,11 @@ class ThreadSafeCircularList:
         async with self.lock:
             if self.schedule_algorithm == "fixed_priority":
                 self.index = 0
+
+            # 检查是否即将完成一个循环，并据此触发重排序
+            if self.schedule_algorithm == "smart_round_robin" and len(self.items) > 0 and self.index == len(self.items) - 1:
+                self._trigger_reorder()
+
             start_index = self.index
             while True:
                 item = self.items[self.index]
@@ -374,9 +425,35 @@ class ThreadSafeCircularList:
 
                 # 如果已经检查了所有的 API key 都被限制
                 if self.index == start_index:
-                    logger.warning(f"All API keys are rate limited!")
+                    logger.warning("All API keys are rate limited!")
                     raise HTTPException(status_code=429, detail="Too many requests")
 
+    async def is_tpr_exceeded(self, model: str = None, tokens: int = 0) -> bool:
+        """Checks if the request exceeds the TPR (Tokens Per Request) limit."""
+        if not tokens:
+            return False
+
+        async with self.lock:
+            rate_limit = None
+            model_key = model or "default"
+            if model and model_key in self.rate_limits:
+                rate_limit = self.rate_limits[model_key]
+            else:
+                # fuzzy match
+                for limit_model in self.rate_limits:
+                    if limit_model != "default" and model and limit_model in model:
+                        rate_limit = self.rate_limits[limit_model]
+                        break
+            if rate_limit is None:
+                rate_limit = self.rate_limits.get("default", [])
+
+            for limit_count, limit_period in rate_limit:
+                if limit_period == -1:  # TPR limit
+                    if tokens > limit_count:
+                        # logger.warning(f"API provider for model {model_key} exceeds TPR limit ({tokens}/{limit_count}).")
+                        return True
+        return False
+
     async def is_all_rate_limited(self, model: str = None) -> bool:
         """检查是否所有的items都被速率限制
 
@@ -449,10 +526,10 @@ provider_api_circular_list = defaultdict(ThreadSafeCircularList)
 c35s = ThreadSafeCircularList(["us-east5", "europe-west1"])
 c3s = ThreadSafeCircularList(["us-east5", "us-central1", "asia-southeast1"])
 c3o = ThreadSafeCircularList(["us-east5"])
-c4 = ThreadSafeCircularList(["us-east5", "us-central1", "europe-west4", "asia-southeast1"])
+c4 = ThreadSafeCircularList(["us-east5", "europe-west1", "asia-east1"])
 c3h = ThreadSafeCircularList(["us-east5", "us-central1", "europe-west1", "europe-west4"])
 gemini1 = ThreadSafeCircularList(["us-central1", "us-east4", "us-west1", "us-west4", "europe-west1", "europe-west2"])
-gemini2 = ThreadSafeCircularList(["us-central1"])
+gemini_preview = ThreadSafeCircularList(["global"])
 # gemini2_5_pro_exp = ThreadSafeCircularList(["global"])
 gemini2_5_pro_exp = ThreadSafeCircularList([
   "us-central1",
@@ -479,8 +556,6 @@ end_of_line = "\n\n"
 # end_of_line = "\r"
 # end_of_line = "\n"
 
-import random
-import string
 async def generate_sse_response(timestamp, model, content=None, tools_id=None, function_call_name=None, function_call_content=None, role=None, total_tokens=0, prompt_tokens=0, completion_tokens=0, reasoning_content=None, stop=None):
     random.seed(timestamp)
     random_str = ''.join(random.choices(string.ascii_letters + string.digits, k=29))
@@ -618,7 +693,7 @@ def get_image_format(file_content: bytes):
     try:
         img = Image.open(io.BytesIO(file_content))
         return img.format.lower()
-    except:
+    except Exception:
         return None
 
 def encode_image(file_content: bytes):
@@ -770,6 +845,44 @@ def parse_json_safely(json_str):
             # 两种方法都失败，抛出异常
             raise Exception(f"无法解析JSON字符串: {e}, {json_str}")
 
+async def upload_image_to_0x0st(base64_image: str):
+    """
+    Uploads a base64 encoded image to 0x0.st.
+
+    Args:
+        base64_image: The base64 encoded image string.
+
+    Returns:
+        The URL of the uploaded image.
+    """
+    if "," in base64_image:
+        base64_image_split = base64_image.split(",")[1]
+
+    image_data = base64.b64decode(base64_image_split)
+
+    img_format = get_image_format(image_data)
+    if not img_format:
+        img_format = 'png'  # 如果无法检测到格式，则默认为 png
+
+    content_type = f'image/{img_format}'
+    file_name = f'image.{img_format}'
+
+    files = {'file': (file_name, image_data, content_type)}
+    data = {'expires': '24', 'secret': '123456'}
+
+    async with httpx.AsyncClient() as client:
+        try:
+            response = await client.post("https://0x0.st", files=files, data=data)
+            response.raise_for_status()
+            return response.text.strip()
+        except httpx.RequestError as e:
+            logger.error(f"请求 0x0.st 时出错: {e}")
+            # raise HTTPException(status_code=500, detail="上传图片到 0x0.st 失败")
+        except httpx.HTTPStatusError as e:
+            logger.error(f"上传图片到 0x0.st 时发生 HTTP 错误: {e.response.status_code}")
+            # raise HTTPException(status_code=e.response.status_code, detail=f"上传图片到 0x0.st 失败: {e.response.text}")
+        return base64_image
+
 if __name__ == "__main__":
     provider = {
         "base_url": "https://gateway.ai.cloudflare.com/v1/%7Baccount_id%7D/%7Bgateway_id%7D/google-vertex-ai",
