@@ -80,6 +80,21 @@ class TaskComplete(Exception):
         self.completion_message = message
         super().__init__(f"Task completed with message: {message}")
 
+# 结尾重复响应错误
+class RepetitiveResponseError(Exception):
+    """Custom exception for detecting repetitive and meaningless generated strings."""
+    def __init__(self, message, phrase, count):
+        super().__init__(message)
+        self.phrase = phrase
+        self.count = count
+
+
+class AllToolsMissingParametersError(Exception):
+    """Custom exception for when all tools are missing required parameters."""
+    def __init__(self, message, response_text):
+        super().__init__(message)
+        self.response_text = response_text
+
 
 class chatgpt(BaseLLM):
     """
@@ -172,7 +187,7 @@ class chatgpt(BaseLLM):
         """
         Add a message to the conversation
         """
-        # self.logger.info(f"role: {role}, function_name: {function_name}, message: {message}")
+        # self.logger.info(f"role: {role}, function_name: {function_name}, message: {message}, function_arguments: {function_arguments}")
         if convo_id not in self.conversation:
             self.reset(convo_id=convo_id)
         if function_name == "" and message:
@@ -276,9 +291,9 @@ class chatgpt(BaseLLM):
         }
 
         done_message = self.conversation[convo_id].provider("done")
-        if self.check_done and done_message:
+        if done_message:
             done_message.visible = False
-            if self.conversation[convo_id][-1][-1].name == "done":
+            if self.check_done and self.conversation[convo_id][-1][-1].name == "done":
                 self.conversation[convo_id][-1][-1].visible = True
 
         # 构造请求数据
@@ -492,6 +507,9 @@ class chatgpt(BaseLLM):
                             missing_required_params.append(f"Error: {tool_name} missing required parameters: {missing_required_params}")
                 function_parameter = valid_function_parameters
 
+                if not function_parameter and missing_required_params:
+                    raise AllToolsMissingParametersError("\n\n".join(missing_required_params), response_text=full_response)
+
                 # 删除 task_complete 跟其他工具一起调用的情况，因为 task_complete 必须单独调用
                 if len(function_parameter) > 1:
                     function_parameter = [tool_dict for tool_dict in function_parameter if tool_dict.get("function_name", "") != "task_complete"]
@@ -607,11 +625,16 @@ class chatgpt(BaseLLM):
                 final_tool_response = tool_response
                 if "<tool_error>" not in tool_response:
                     if tool_name == "read_file":
-                        self.conversation[convo_id].provider("files").update(tool_info['parameter']["file_path"], tool_response)
+                        self.conversation[convo_id].provider("files").update(tool_info['parameter']["file_path"], tool_response, head=safe_get(tool_info, 'parameter', "head", default=None))
                         final_tool_response = "Read file successfully! The file content has been updated in the tag <latest_file_content>."
                     elif tool_name == "get_knowledge_graph_tree":
                         self.conversation[convo_id].provider("knowledge_graph").visible = True
                         final_tool_response = "Get knowledge graph tree successfully! The knowledge graph tree has been updated in the tag <knowledge_graph_tree>."
+                    elif tool_name.endswith("goal"):
+                        goal_provider = self.conversation[convo_id].provider("goal")
+                        if goal_provider:
+                            goal_provider += f"\n\n<{tool_name}>{tool_response}</{tool_name}>"
+                        final_tool_response = "Get goal successfully! The goal has been updated in the tag <goal>."
                     elif tool_name == "write_to_file":
                         tool_args = None
                     elif tool_name == "read_image":
@@ -660,17 +683,6 @@ class chatgpt(BaseLLM):
             self.add_to_conversation(full_response, response_role, convo_id=convo_id, total_tokens=total_tokens, pass_history=pass_history)
             self.function_calls_counter = {}
 
-            # 清理翻译引擎相关的历史记录
-            if pass_history <= 2 and len(self.conversation[convo_id]) >= 2 \
-            and (
-                "You are a translation engine" in self.conversation[convo_id][-2]["content"] \
-                or "You are a translation engine" in safe_get(self.conversation, convo_id, -2, "content", 0, "text", default="") \
-                or "你是一位精通简体中文的专业翻译" in self.conversation[convo_id][-2]["content"] \
-                or "你是一位精通简体中文的专业翻译" in safe_get(self.conversation, convo_id, -2, "content", 0, "text", default="")
-            ):
-                self.conversation[convo_id].pop(-1)
-                self.conversation[convo_id].pop(-1)
-
     async def _ask_stream_handler(
         self,
         prompt: list,
@@ -691,7 +703,9 @@ class chatgpt(BaseLLM):
         Unified stream handler (async)
         """
         # 准备会话
-        self.system_prompt = system_prompt or self.system_prompt
+        if system_prompt and system_prompt != self.system_prompt:
+            self.system_prompt = system_prompt or self.system_prompt
+            self.conversation[convo_id][0] = SystemMessage(self.system_prompt)
         if convo_id not in self.conversation or pass_history <= 2:
             self.reset(convo_id=convo_id, system_prompt=self.system_prompt)
         self.add_to_conversation(prompt, role, convo_id=convo_id, function_name=function_name, total_tokens=total_tokens, function_arguments=function_arguments, pass_history=pass_history, function_call_id=function_call_id)
@@ -808,9 +822,19 @@ class chatgpt(BaseLLM):
                     {"role": "user", "content": "你的消息没有以[done]结尾，请重新输出"}
                 ]
                 continue
+            except AllToolsMissingParametersError as e:
+                self.logger.warning(f"All tools are missing required parameters: {e}. Retrying with corrective prompt.")
+                need_done_prompt = [
+                    {"role": "assistant", "content": e.response_text},
+                    {"role": "user", "content": f"{str(e)}，请重新输出"}
+                ]
+                continue
             except EmptyResponseError as e:
                 self.logger.warning(f"{e}, retrying...")
                 continue
+            except RepetitiveResponseError as e:
+                self.logger.warning(f"{e}, retrying...")
+                continue
             except TaskComplete as e:
                 raise
             except ModelNotFoundError as e:
