@@ -4,7 +4,7 @@ from ..aient.aient.plugins import (
     # read_file,
     # read_image,
     register_tool,
-    write_to_file,
+    # write_to_file,
     excute_command,
     # list_directory,
     # get_url_content,
@@ -14,6 +14,9 @@ from ..aient.aient.plugins import (
     # download_read_arxiv_pdf,
 )
 
+from ..aient.aient.architext.architext import Messages, SystemMessage, UserMessage, AssistantMessage, ToolCalls, ToolResults, Texts, RoleMessage, Images, Files
+
+from .write_file import write_to_file
 
 from beswarm.tools import (
     # worker,
@@ -44,13 +47,9 @@ from ..agents.planact import BrokerWorker
 @register_tool()
 def get_task1_goal(query: str):
     """
-    根据用户查询生成任务1的目标。
+    根据用户查询获取任务1的目标。
 
-    这个函数为第一个子任务创建一个详细的提示。该子任务的目标是
-    使用 `search_web` 工具搜索与查询相关的信息，然后使用
-    `create_tasks_from_csv` 工具根据搜索结果创建更多的子任务。
-
-    返回的字符串是一个模版，将用作初始任务的“目标”。
+    返回的字符串将用作初始任务的“目标”。
     它包含了指导AI代理（扮演“首席情报官”）从网络搜索结果构建知识图谱的说明。
 
     参数:
@@ -64,7 +63,7 @@ def get_task1_goal(query: str):
         """
 调用 search_web 工具搜索，该工具会把搜索结果保存到 csv 文件中。
 
-**禁止**读取任何 csv 文件。
+**禁止**使用任何方式读取任何 csv 文件。搜索结果的csv文件是给create_tasks_from_csv工具用的，**禁止**直接读取。
 
 然后使用 create_tasks_from_csv 工具，从 csv 文件中创建多个子任务。
 
@@ -136,7 +135,6 @@ csv 的 title 是 query, url和content，content是url对应的网页内容。qu
 5.  **【第5步：完成任务 (Finalize)】**
     *   只有当你确认知识图谱（情报简报）在**结构、逻辑、深度和洞察力**上都达到了你作为**首席情报官**的最高标准时，才能调用 `task_complete` 结束你的任务。
 ```
-
 观察知识图谱，如果当前信息不足以回答用户的查询，则继续从不同角度搜索，直到信息足够为止。继续循环上一个子任务，直到信息足够为止。
         """
     )
@@ -203,7 +201,7 @@ def get_task2_goal(query: str):
     *   当你对这篇由团队协作完成、并由你亲自统稿的报告感到满意时，编写执行摘要和战略展望章节，编写脚本通过 excute_command 使用 cat 和输出重定向进行文件内容拼接将所有章节合并到同一个md文件保存到本地，最后调用 `task_complete`，并将**最终的、完整的Markdown报告全文的文件路径**作为`message`参数返回。
 
 ---
-### **【分析师专用】子任务`goal`** (注意：这是子任务的`goal`，填入必要信息后，传给子-任务执行)
+### **【分析师专用】子任务`goal`** (注意：这是子任务的`goal`，填入必要信息后，将下面的goal原样完整传给子-任务执行，不要修改)
 
 **任务:** 你是一位专业的领域分析师。你的总编辑已经为你规划好了整篇报告的结构，并为你分配了具体的章节撰写任务。
 
@@ -277,13 +275,15 @@ async def deepsearch(query: str, work_dir: str):
 
     goal = f"""
 **禁止**执行 get_task1_goal，get_task2_goal。
+第一个子任务的 tool 必须有 get_task1_goal，第二个子任务的 tool 必须有 get_task2_goal。
 
 使用 create_task 启动第一个子任务，下面是 goal 原文，请将```内字符串原样传入，不要修改：
 
 ```
 用户查询：{query}
 
-使用get_task1_goal获取任务安排。
+首先调用get_task1_goal获取任务安排。
+等待所有子任务全部完成。
 ```
 
 使用 create_task 第一个子任务结束后，启动第二个子任务，第二个子任务需要 excute_command 工具，下面是 goal 原文，请将```内字符串原样传入，不要修改：
@@ -292,10 +292,10 @@ async def deepsearch(query: str, work_dir: str):
 用户查询：{query}
 
 使用get_task2_goal获取任务安排。
+```
 
 务必先执行第一个子任务，等第一个子任务完成后，再执行第二个子任务。
 等待两个子任务都完成后，才调用 task_complete 结束任务。
-```
 """
 
     worker_instance = BrokerWorker(goal, tools, work_dir, True, broker, mcp_manager, task_manager, kgm)
