@@ -51,7 +51,13 @@ async def search_web(query: str):
         async with httpx.AsyncClient() as client:
             response = await client.post(api_url, headers=headers, data=payload)
             response.raise_for_status()  # 如果状态码是 4xx 或 5xx，则引发 HTTPStatusError
-            results = json.loads(response.json())
+            # The API can return either a JSON object or a string containing JSON.
+            # This handles both cases to avoid a TypeError.
+            decoded_response = response.json()
+            if isinstance(decoded_response, str):
+                results = json.loads(decoded_response)
+            else:
+                results = decoded_response
     except httpx.HTTPStatusError as e:
         return {
             "error": f"HTTP error occurred: {e.response.status_code} - {e.response.text}",
