@@ -1,6 +1,6 @@
 import ast
 from pathlib import Path
-from ..core import current_task_manager
+from ..core import current_task_manager, current_work_dir
 from ..aient.aient.plugins import register_tool, registry
 
 worker_fun = registry.tools["worker"]
@@ -24,6 +24,13 @@ def create_task(goal, tools, work_dir):
         str: 当任务成功完成时，返回字符串 "任务已完成"。
     """
     task_manager = current_task_manager.get()
+    main_work_dir = current_work_dir.get()
+
+    if os.path.isabs(work_dir):
+        final_path = work_dir
+    else:
+        final_path = os.path.join(main_work_dir, work_dir)
+    work_dir = os.path.abspath(final_path)
 
     # 检查工作目录是否与现有任务重复
     for task_id, task_info in task_manager.tasks_cache.items():
